package dk.vajhoej.vms.call.lib;

import dk.vajhoej.record.Alignment;
import dk.vajhoej.record.FieldType;
import dk.vajhoej.record.RecordException;
import dk.vajhoej.record.Struct;
import dk.vajhoej.record.StructField;
import dk.vajhoej.record.StructInfoCache;

import static dk.vajhoej.vms.call.lib.VMSCodes.*;

/**
 * Class FAB represents a FAB (File Access Block) block.
 */
@Struct(alignment=Alignment.PACKED)
public class FAB {
	@StructField(n=0,type=FieldType.INT1)
	private int bid;
	@StructField(n=1,type=FieldType.INT1)
	private int bln;
	@StructField(n=2,type=FieldType.INT2)
	private int ifi;
	@StructField(n=3,type=FieldType.INT4)
	private int fop;
	@StructField(n=4,type=FieldType.INT4)
	private int sts;
	@StructField(n=5,type=FieldType.INT4)
	private int stv;
	@StructField(n=6,type=FieldType.INT4)
	private int alq;
	@StructField(n=7,type=FieldType.INT2)
	private int deq;
	@StructField(n=8,type=FieldType.INT1)
	private int fac;
	@StructField(n=9,type=FieldType.INT1)
	private int shr;
	@StructField(n=10,type=FieldType.INT4)
	private int ctx;
	@StructField(n=11,type=FieldType.INT1)
	private int rtv;
	@StructField(n=12,type=FieldType.INT1)
	private int org;
	@StructField(n=13,type=FieldType.INT1)
	private int rat;
	@StructField(n=14,type=FieldType.INT1)
	private int rfm;
	@StructField(n=15,type=FieldType.INT4)
	private int jnl;
	@StructField(n=16,type=FieldType.INT4)
	private int xab;
	@StructField(n=17,type=FieldType.INT4)
	private int nam;
	@StructField(n=18,type=FieldType.INT4)
	private int fna;
	@StructField(n=19,type=FieldType.INT4)
	private int dna;
	@StructField(n=20,type=FieldType.INT1)
	private int fns;
	@StructField(n=21,type=FieldType.INT1)
	private int dns;
	@StructField(n=22,type=FieldType.INT2)
	private int mrs;
	@StructField(n=23,type=FieldType.INT4)
	private int mrn;
	@StructField(n=24,type=FieldType.INT2)
	private int bls;
	@StructField(n=25,type=FieldType.INT1)
	private int bks;
	@StructField(n=26,type=FieldType.INT1)
	private int fsz;
	@StructField(n=27,type=FieldType.INT4)
	private int dev;
	@StructField(n=28,type=FieldType.INT4)
	private int sdc;
	@StructField(n=29,type=FieldType.INT2)
	private int gbc;
	@StructField(n=30,type=FieldType.INT1)
	private int acmodes;
	@StructField(n=31,type=FieldType.INT1)
	private int rcf;
	@StructField(n=32,type=FieldType.INT4)
	private int fill;
	private transient String filename;
	private static int FABLEN;
	static {
		try {
			FABLEN = StructInfoCache.analyze(FAB.class).getLength();
		} catch (RecordException e) {
			throw new RuntimeException("Internal problem: " + e);
		}
	}
	public FAB() {
		this.bid = FAB$C_BID;
		this.bln = FABLEN;
		this.ifi = 0;
		this.xab = 0;
		this.nam = 0;
		this.fna = 0;
		this.dna = 0;
		this.filename = null;
	}
	public FAB(String filename, int fac, int shr, int fop) {
		this();
		this.filename = filename;
		this.fns = filename.length();
		this.fac = fac;
		this.shr = shr;
		this.fop = fop;
	}
	public FAB(String filename, int fac, int shr, int fop, int org, int rfm, int rat) {
		this(filename, fac, shr, fop);
		this.org = org;
		this.rfm = rfm;
		this.rat = rat;
	}
	public int getFac() {
		return fac;
	}
	public void setFac(int fac) {
		this.fac = fac;
	}
	public int getFop() {
		return fop;
	}
	public void setFop(int fop) {
		this.fop = fop;
	}
	public int getShr() {
		return shr;
	}
	public void setShr(int shr) {
		this.shr = shr;
	}
	public int getOrg() {
		return org;
	}
	public void setOrg(int org) {
		this.org = org;
	}
	public int getRat() {
		return rat;
	}
	public void setRat(int rat) {
		this.rat = rat;
	}
	public int getRfm() {
		return rfm;
	}
	public void setRfm(int rfm) {
		this.rfm = rfm;
	}
	public int getMrs() {
		return mrs;
	}
	public void setMrs(int mrs) {
		this.mrs = mrs;
	}
	public String getFilename() {
		return filename;
	}
	public void setFilename(String filename) {
		this.filename = filename;
	}
}
