/*
 * Copyright 2017 Arne Vajhj.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License. 
 */

package dk.vajhoej.vms.call.test;

import static dk.vajhoej.vms.call.VMS.isSuccess;
import static org.junit.Assert.*;

import java.util.List;
import java.util.Map;

public class BaseTest {
	private boolean debug;
	public BaseTest() {
		debug = System.getProperty("test.debug") != null;
	}
	public void assertVMSCall(String descrip, int sts) {
		if(debug) System.out.printf("sts = %d\n", sts);
        assertTrue(descrip + " status", isSuccess(sts));
	}
	public void assertVMSCall(String descrip, int sts, int ival) {
		if(debug) System.out.printf("sts = %d\n", sts);
        assertTrue(descrip + " status", isSuccess(sts));
        if(debug) System.out.printf("res = %d\n", ival);
        assertTrue(descrip + " result > 0", ival > 0);
	}
	public void assertVMSCall(String descrip, int sts, long lval) {
		if(debug) System.out.printf("sts = %d\n", sts);
        assertTrue(descrip + " status", isSuccess(sts));
        if(debug) System.out.printf("res = %d\n", lval);
        assertTrue(descrip + " result > 0", lval > 0);
	}
	public void assertVMSCall(String descrip, int sts, String sval) {
		if(debug) System.out.printf("sts = %d\n", sts);
        assertTrue(descrip + " status", isSuccess(sts));
        if(debug) System.out.printf("res = %s\n", sval);
        assertTrue(descrip + " result length > 0", sval.length() > 0);
	}
	public void assertVMSCall(String descrip, int sts, boolean bval) {
		if(debug) System.out.printf("sts = %d\n", sts);
        assertTrue(descrip + " status", isSuccess(sts));
        if(debug) System.out.printf("res = %b\n", bval);
        assertTrue(descrip + " result", bval);
	}
	public void assertVMSCall(String descrip, int sts, List<?> lval) {
		if(debug) System.out.printf("sts = %d\n", sts);
        assertTrue(descrip + " status", isSuccess(sts));
        if(debug) System.out.printf("res = %s\n", lval.toString());
        assertTrue(descrip + " result number elements > 0", lval.size() > 0);
	}
	public void assertVMSCall(String descrip, int sts, Map<?,?> mval) {
		if(debug) System.out.printf("sts = %d\n", sts);
        assertTrue(descrip + " status", isSuccess(sts));
        if(debug) System.out.printf("res = %s\n", mval.toString());
        assertTrue(descrip + " result number entries > 0", mval.size() > 0);
	}
}
